==> PGCup_2002_08_06.tar.gz: PGCup/sources/pgclibrary/objects/TableColumn.java <==
/*
 * TableColumn.java
 *
 * Created on 31 de julio de 2002, 09:20
 */

package pgclibrary.objects;
import java.util.*;
import java.sql.*;
import pgclibrary.dataaccess.*;

/**
 *
 * @author  nestor
 */
public class TableColumn extends DBObject {
    private int col_number = 0;
    private int size = 0;
    private boolean allow_nulls = false;
    private AttributeType column_type = null;
    private String default_value = new String();
    
    public TableColumn(DBObject owner, long oid) {
        super(owner);
        search(oid);
    }
    
    /** Retrieve the SQL string that eliminate this object from
     * the database.
     * @return SQL DML string.
     */
    public String getDeleteSQL() {
        return new String();
    }
    
    /** Returns the SQL string that
     * generate this object.
     * @return SQL DML instruction for generation.
     */
    public String getInsertSQL() {
        StringBuffer retorno = new StringBuffer(30);
        retorno.append(getName());
        retorno.append(" ");
        
        if(getColumnType() != null){
            retorno.append(getColumnType().getName().toUpperCase());
            retorno.append(" ");
            if(getColumnType().getSize() < 0){
                retorno.append("(");
                retorno.append(getSize());
                retorno.append(") ");
            }
        }
        if(!allowNulls()){
            retorno.append("NOT NULL ");
        }
        if(getDefaultValue() != null){
            retorno.append("DEFAULT ");
            retorno.append(getDefaultValue());
        }
        return retorno.toString();
    }
    
    /** Retrieve the SQL String that implements this
     * object modifications.
     * @return SQL DML String.
     */
    public String getUpdateSQL() {
        return new String();
    }
    
    /** Find the object asociated with the OID.
     * @param _oid OID to search.
     * @return true if the object was found
     */
    public boolean search(long _oid) {
        boolean retorno = false;
        try{
            initialize();
            PreparedStatement prep = getConnection().prepareStatement("select "
            + " pg_attribute.OID, pg_attribute.attnum, pg_attribute.attname, "
            + " case when pg_attribute.attlen > 0 then pg_attribute.attlen "
            + "                 else pg_attribute.atttypmod-4 end as colsize, "
            + " not pg_attribute.attnotnull as allownull, "
            + " adsrc as DEFAULT, pg_attribute.attnelems as vector_elements, "
            + " pg_attribute.attrelid, pg_attribute.oid, pg_attribute.atttypid "
            + " from pg_attribute "
            + "   LEFT JOIN pg_attrdef "
            + "       ON (pg_attribute.attrelid = pg_attrdef.adrelid "
            + "             and pg_attribute.attnum = pg_attrdef.adnum) "
            + " where pg_attribute.attrelid = ? AND pg_attribute.ATTNUM=? ");
            prep.setLong(1, getOwner().getOID());
            prep.setLong(2, _oid);
            ResultSet rs = prep.executeQuery();
            if((rs != null) && (rs.next())){
                setOID(rs.getLong("OID"));
                setName(rs.getString("ATTNAME"));
                setColumnNumber(rs.getInt("attnum"));
                setSize(rs.getInt("COLSIZE"));
                setAllowNulls(rs.getBoolean("ALLOWNULL"));
                setColumnType(AttributeType.searchObject(rs.getLong("atttypid")));
                setDefaultValue(rs.getString("DEFAULT"));
                retorno = true;
            }
            rs.close();
            prep.close();
        } catch (SQLException e){
            e.printStackTrace();
        }
        return retorno;
    }
    
    public void initialize(){
        super.initialize();
        col_number = 0;
        size = 0;
        allow_nulls = false;
        column_type = null;
        default_value = new String();
    }
    
    // ---------SET AND GET-------------
    private void setDefaultValue(String _value){
        if(_value == null){
            default_value = new String();
        } else {
            default_value = _value;
        }
    }
    public String getDefaultValue(){
        return default_value;
    }
    
    private void setColumnNumber(int _col_number){
        col_number = _col_number;
    }
    public int getColumnNumber(){
        return col_number;
    }
    
    private void setSize(int _size){
        size = _size;
    }
    public int getSize(){
        if(size > 0){
            return size;
        } else {
            return column_type.getSize();
        }
    }
    
    private void setAllowNulls(boolean _allow_nulls){
        allow_nulls = _allow_nulls;
    }
    public boolean allowNulls(){
        return allow_nulls;
    }
    
    public AttributeType getColumnType(){
        return column_type;
    }
    private void setColumnType(AttributeType _column_type){
        column_type = _column_type;
    }
}

==> PGCup_2002_08_08.tar.gz: PGCup/sources/pgclibrary/objects/TableColumn.java <==
/*
 * TableColumn.java
 *
 * Created on 31 de julio de 2002, 09:20
 */

package pgclibrary.objects;
import java.util.*;
import java.sql.*;
import pgclibrary.dataaccess.*;

/**
 *
 * @author  nestor
 */
public class TableColumn extends DBObject {
    private int col_number = 0;
    private int size = 0;
    private boolean allow_nulls = false;
    private AttributeType column_type = null;
    private String default_value = new String();
    
    public TableColumn(DBObject owner, long oid) {
        super(owner);
        search(oid);
    }
    
    /** Retrieve the SQL string that eliminate this object from
     * the database.
     * @return SQL DML string.
     */
    public String getDeleteSQL() {
        return new String();
    }
    
    /** Returns the SQL string that
     * generate this object.
     * @return SQL DML instruction for generation.
     */
    public String getInsertSQL() {
        StringBuffer retorno = new StringBuffer(30);
        retorno.append(getName());
        retorno.append(" ");
        
        if(getColumnType() != null){
            retorno.append(getColumnType().getName().toUpperCase());
            retorno.append(" ");
            if(getColumnType().getSize() < 0){
                retorno.append("(");
                retorno.append(getSize());
                retorno.append(") ");
            }
        }
        if(!allowNulls()){
            retorno.append("NOT NULL ");
        }
        if ((getDefaultValue() != null) && (getDefaultValue().trim().length() > 0)){
            retorno.append("DEFAULT ");
            retorno.append(getDefaultValue());
        }
        return retorno.toString();
    }
    
    /** Retrieve the SQL String that implements this
     * object modifications.
     * @return SQL DML String.
     */
    public String getUpdateSQL() {
        return new String();
    }
    
    /** Find the object asociated with the OID.
     * @param _oid OID to search.
     * @return true if the object was found
     */
    public boolean search(long _oid) {
        boolean retorno = false;
        try{
            initialize();
            PreparedStatement prep = getConnection().prepareStatement("select "
            + " pg_attribute.OID, pg_attribute.attnum, pg_attribute.attname, "
            + " case when pg_attribute.attlen > 0 then pg_attribute.attlen "
            + "                 else pg_attribute.atttypmod-4 end as colsize, "
            + " not pg_attribute.attnotnull as allownull, "
            + " adsrc as DEFAULT, pg_attribute.attnelems as vector_elements, "
            + " pg_attribute.attrelid, pg_attribute.oid, pg_attribute.atttypid "
            + " from pg_attribute "
            + "   LEFT JOIN pg_attrdef "
            + "       ON (pg_attribute.attrelid = pg_attrdef.adrelid "
            + "             and pg_attribute.attnum = pg_attrdef.adnum) "
            + " where pg_attribute.attrelid = ? AND pg_attribute.ATTNUM=? ");
            prep.setLong(1, getOwner().getOID());
            prep.setLong(2, _oid);
            ResultSet rs = prep.executeQuery();
            if((rs != null) && (rs.next())){
                setOID(rs.getLong("OID"));
                setName(rs.getString("ATTNAME"));
                setColumnNumber(rs.getInt("attnum"));
                setSize(rs.getInt("COLSIZE"));
                setAllowNulls(rs.getBoolean("ALLOWNULL"));
                setColumnType(AttributeType.searchObject(rs.getLong("atttypid")));
                setDefaultValue(rs.getString("DEFAULT"));
                retorno = true;
            }
            rs.close();
            prep.close();
        } catch (SQLException e){}
        return retorno;
    }
    
    public void initialize(){
        super.initialize();
        col_number = 0;
        size = 0;
        allow_nulls = false;
        column_type = null;
        default_value = new String();
    }
    
    // ---------SET AND GET-------------
    private void setDefaultValue(String _value){
        if(_value == null){
            default_value = new String();
        } else {
            default_value = _value;
        }
    }
    public String getDefaultValue(){
        return default_value;
    }
    
    private void setColumnNumber(int _col_number){
        col_number = _col_number;
    }
    public int getColumnNumber(){
        return col_number;
    }
    
    private void setSize(int _size){
        size = _size;
    }
    public int getSize(){
        if(size > 0){
            return size;
        } else {
            return column_type.getSize();
        }
    }
    
    private void setAllowNulls(boolean _allow_nulls){
        allow_nulls = _allow_nulls;
    }
    public boolean allowNulls(){
        return allow_nulls;
    }
    
    public AttributeType getColumnType(){
        return column_type;
    }
    private void setColumnType(AttributeType _column_type){
        column_type = _column_type;
    }
}
